# Maintainers

- [RDIL](https://github.com/RDIL) *(Team Lead)*
- [CoffeeGoddess](https://github.com/CoffeeGoddess)

# Contributors

- 73VW
- Wittionary
- jerry-le
- Yugaank-Kalia
- dylanfw
- BallisticZer0
- ninexball
- MatthewStanciu
- Emanuelh77
- kritokrator
- danieldeveloper001
- brndmfrd
- kurokochin
- brtln
- Plutoberth
- DirtySoc
- amrutha3
- fkorotkov
- water900
- rocketpropelledpotato
- theonetheonlydemon
- N8python
